==> nextcloud-27.1.2.tgz: nextcloud/apps/activity/l10n/eo.js <==
OC.L10N.register(
    "activity",
    {
    "Copied!" : "Kopiita!",
    "Not supported!" : "Ne subtenite!",
    "Press ⌘-C to copy." : "Premi ⌘-C por kopii.",
    "Press Ctrl-C to copy." : "Premi Ctrl-C por kopii.",
    "{name} (invisible)" : "{name} (nevidebla)",
    "{name} (restricted)" : "{name} (limigita)",
    "Home" : "Hejmo",
    "in {path}" : "ene de {path}",
    "This stream will show events like additions, changes & shares" : "Tiu ĉi fluo montros eventojn kiel aldonojn, ŝanĝojn kaj kunhavigojn",
    "There are no events for this filter" : "Neniu evento kun tiu ĉi filtrilo",
    "Today" : "Hodiaŭ",
    "Yesterday" : "Hieraŭ",
    "Open {filename}" : "Malfermi {filename}",
    "Activity" : "Aktivaĵoj",
    "Personal activity feed for %s" : "Propra aktivaĵa fluo por %s",
    "Your feed URL is invalid" : "Via fluo-adreso ne validas",
    "Your settings have been updated." : "Viaj agordoj ĝisdatiĝis.",
    "Settings have been updated." : "Agordoj estis ĝisdatigitaj.",
    "Recent activity" : "Lastatempa aktiveco",
    "No activities" : "Neniu aktivaĵo",
    "More activities" : "Pli da aktivecoj",
    "Daily activity summary for %s" : "Taga resumo de aktiveco por %s",
    "_and %n more _::_and %n more _" : ["kaj %n aliaj ","kaj %n aliaj "],
    "All activities" : "Ĉiuj aktivaĵoj",
    "By others" : "De aliuloj",
    "By you" : "De vi",
    "Activity at %s" : "Aktiveco ĉe %s",
    "Hello %s" : "Saluton %s",
    "Hello %s," : "Saluton %s,",
    "There was some activity at %s" : "Okazis kelkaj aktivaĵoj en %s",
    "Mail" : "Retpoŝto",
    "Push" : "Puŝi",
    "Notifications" : "Atentigoj",
    "This application enables people to view a log of activities about them, their files or other data." : "Tiu ĉi aplikaĵo permesas al homoj vidi protokolon de aktivecoj pri ili, iliaj dosieroj aŭ aliaj datumoj.",
    "This app allows people to see actions related to their files and data in Nextcloud.\n\t\tEach person can configure their individual activity settings in the personal settings,\n\t\tto choose which activity should be pushed to mobile phones, sent via email\n\t\tor whether a daily summary is sent each morning.\n\t\tMore information is available in the Activity documentation." : "Tiu programo permesas al homoj vidi agojn ligitajn al iliaj dosieroj kaj datenoj en Nextcloud.\n\t\tĈiu persono povas agordi siajn individuajn agadajn agordojn en la personaj agordoj,\n\t\tpor elekti, kian agadon oni devas puŝi al poŝtelefonoj, senditaj per retpoŝto\n\t\taŭ ĉu ĉiutaga resumo estas sendita ĉiumatene.\n\t\tPli detalaj informoj troveblas en Aktivaĵo dokumentado.",
    "Activity notification configuration" : "Agordoj de aktivaĵaj atentigoj",
    "Send email" : "Sendi retpoŝtmesaĝon",
    "Send push notification" : "Sendi puŝan atentigon",
    "You need to set up your email address before you can receive notification emails." : "Vi bezonas agordi vian retpoŝtadreson por povi ricevi sciigojn retmesaĝe.",
    "Send activity emails" : "Sendi aktivaĵajn retmesaĝojn",
    "As soon as possible" : "Kiel eble plej baldaŭ",
    "Hourly" : "Ĉiuhore",
    "Daily" : "Ĉiutage",
    "Weekly" : "Ĉiusemajne",
    "No activity yet" : "Ankoraŭ neniu aktivaĵo",
    "Unable to load the activity list" : "Ne eblis ŝargi la liston de aktivaĵoj",
    "Notification" : "Atentigo",
    "Enable notification emails" : "Ebligi atentigajn retmesaĝojn",
    "Choose for which activities you want to get an email or push notification." : "Elektu por kiuj aktivaĵoj vi volas ricevi retpoŝton aŭ puŝan sciigon.",
    "Choose for which activities you want to get a push notification." : "Elektu por kiuj aktivaĵoj vi volas ricevi puŝan sciigon.",
    "Daily activity summary" : "Ĉiutaga resumo de aktivaĵoj",
    "Send daily activity summary in the morning" : "Sendu ĉiutagajn aktivaĵajn resumojn matene",
    "Default settings" : "Defaŭltaj agordoj",
    "Configure the default notification settings for new accounts." : "Agordi la defaŭltajn sciigajn agordojn por novaj kontoj.",
    "Unable to save the settings" : "Ne eblis konservi la agordojn",
    "Activity feed" : "Aktivaĵa fluo",
    "Activity settings" : "Agordoj de aktivaĵoj",
    "Enable RSS feed" : "Aktivigi RSS-fluon",
    "RSS feed" : "RSS-a fluo",
    "Copy RSS feed link" : "Kopii RSS-fluan ligilon",
    "Personal notification settings" : "Agordoj de persona sciigo",
    "No more events to load" : "Ne plu ŝargeblaj eventoj",
    "This application enables users to view a log of activities about them or about files." : "Tiu aplikaĵo ebligas uzantojn rigardi protokolon de aktivaĵoj pri ili aŭ pri dosieroj.",
    "This application enables users to view actions related to their files in Nextcloud.\n\t\tOnce enabled, users will see a new icon “Activity” in their apps menu.\n\t\tWhen clicked, a new page appears for users to track the activity related to files – from new files, to deleted files, move, rename, updates and shared activity.\n\t\tThe user can configure their individual activity settings in their personal menu.\n\t\tThis sets the type of activity to record, as well as whether to the user sees their own activities,\n\t\twhether these are only available online, and whether they get an email digest on a regular basis.\n\t\tMore information is available in the Activity documentation." : "Tiu ĉi aplikaĵo ebligas uzantojn vidi kio okazas al iliaj dosieroj en Nextcloud..\n\t\tKiam ŝaltita, uzantoj vidos novan bildsimbolon „Aktivaĵoj“ en ilia aplikaĵa menuo.\n\t\tKiam oni alklakas ĝin, nova paĝo montriĝas kaj ebligas al oni sekvi la aktivaĵojn pri la dosieroj — dosieroj novaj, forigitaj, movitaj, alinomitaj, ĝisdatigitaj kaj kunhavigitaj —.\n\t\tLa uzanto povas agordi sian aktivecon en la persona menuo.\n\t\tTiu ebligas elekti lin/ŝin kian tipon de aktivaĵoj registri, kaj ankaŭ ĉu la uzanto volas vidi siajn aktivaĵojn,\n\t\tĉu tiuj disponeblas rete, ĉu ricevi mesaĝaran retmesaĝon regule.\n\t\tPli da informoj en la dokumentado pri Aktivaĵoj.",
    "Activities" : "Aktivaĵoj",
    "Configure the default notification settings for new users." : "Agordi la defaŭltajn sciigajn agordojn por novaj uzantoj."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-27.1.5.tgz: nextcloud/apps/activity/l10n/eo.js <==
OC.L10N.register(
    "activity",
    {
    "Personal activity feed for %s" : "Propra aktivaĵa fluo por %s",
    "Your feed URL is invalid" : "Via fluo-adreso ne validas",
    "Activity feed" : "Aktivaĵa fluo",
    "Your settings have been updated." : "Viaj agordoj ĝisdatiĝis.",
    "Settings have been updated." : "Agordoj estis ĝisdatigitaj.",
    "Recent activity" : "Lastatempa aktiveco",
    "No activities" : "Neniu aktivaĵo",
    "More activities" : "Pli da aktivecoj",
    "Daily activity summary for %s" : "Taga resumo de aktiveco por %s",
    "_and %n more _::_and %n more _" : ["kaj %n aliaj ","kaj %n aliaj "],
    "All activities" : "Ĉiuj aktivaĵoj",
    "By others" : "De aliuloj",
    "By you" : "De vi",
    "Activity at %s" : "Aktiveco ĉe %s",
    "Hello %s" : "Saluton %s",
    "Hello %s," : "Saluton %s,",
    "There was some activity at %s" : "Okazis kelkaj aktivaĵoj en %s",
    "Mail" : "Retpoŝto",
    "Push" : "Puŝi",
    "Activity" : "Aktivaĵoj",
    "Notifications" : "Atentigoj",
    "This application enables people to view a log of activities about them, their files or other data." : "Tiu ĉi aplikaĵo permesas al homoj vidi protokolon de aktivecoj pri ili, iliaj dosieroj aŭ aliaj datumoj.",
    "This app allows people to see actions related to their files and data in Nextcloud.\n\t\tEach person can configure their individual activity settings in the personal settings,\n\t\tto choose which activity should be pushed to mobile phones, sent via email\n\t\tor whether a daily summary is sent each morning.\n\t\tMore information is available in the Activity documentation." : "Tiu programo permesas al homoj vidi agojn ligitajn al iliaj dosieroj kaj datenoj en Nextcloud.\n\t\tĈiu persono povas agordi siajn individuajn agadajn agordojn en la personaj agordoj,\n\t\tpor elekti, kian agadon oni devas puŝi al poŝtelefonoj, senditaj per retpoŝto\n\t\taŭ ĉu ĉiutaga resumo estas sendita ĉiumatene.\n\t\tPli detalaj informoj troveblas en Aktivaĵo dokumentado.",
    "Activity notification configuration" : "Agordoj de aktivaĵaj atentigoj",
    "Send email" : "Sendi retpoŝtmesaĝon",
    "Send push notification" : "Sendi puŝan atentigon",
    "Today" : "Hodiaŭ",
    "Yesterday" : "Hieraŭ",
    "You need to set up your email address before you can receive notification emails." : "Vi bezonas agordi vian retpoŝtadreson por povi ricevi sciigojn retmesaĝe.",
    "Send activity emails" : "Sendi aktivaĵajn retmesaĝojn",
    "As soon as possible" : "Kiel eble plej baldaŭ",
    "Hourly" : "Ĉiuhore",
    "Daily" : "Ĉiutage",
    "Weekly" : "Ĉiusemajne",
    "You commented" : "Vi komentis",
    "Open {filename}" : "Malfermi {filename}",
    "in {path}" : "ene de {path}",
    "Home" : "Hejmo",
    "This stream will show events like additions, changes & shares" : "Tiu ĉi fluo montros eventojn kiel aldonojn, ŝanĝojn kaj kunhavigojn",
    "No activity yet" : "Ankoraŭ neniu aktivaĵo",
    "Activity settings" : "Agordoj de aktivaĵoj",
    "Enable RSS feed" : "Aktivigi RSS-fluon",
    "RSS feed" : "RSS-a fluo",
    "Copy RSS feed link" : "Kopii RSS-fluan ligilon",
    "Personal notification settings" : "Agordoj de persona sciigo",
    "Unable to load the activity list" : "Ne eblis ŝargi la liston de aktivaĵoj",
    "Notification" : "Atentigo",
    "Enable notification emails" : "Ebligi atentigajn retmesaĝojn",
    "Choose for which activities you want to get an email or push notification." : "Elektu por kiuj aktivaĵoj vi volas ricevi retpoŝton aŭ puŝan sciigon.",
    "Choose for which activities you want to get a push notification." : "Elektu por kiuj aktivaĵoj vi volas ricevi puŝan sciigon.",
    "Daily activity summary" : "Ĉiutaga resumo de aktivaĵoj",
    "Send daily activity summary in the morning" : "Sendu ĉiutagajn aktivaĵajn resumojn matene",
    "Default settings" : "Defaŭltaj agordoj",
    "Configure the default notification settings for new accounts." : "Agordi la defaŭltajn sciigajn agordojn por novaj kontoj.",
    "Unable to save the settings" : "Ne eblis konservi la agordojn",
    "No more events to load" : "Ne plu ŝargeblaj eventoj",
    "Copied!" : "Kopiita!",
    "Not supported!" : "Ne subtenite!",
    "Press ⌘-C to copy." : "Premi ⌘-C por kopii.",
    "Press Ctrl-C to copy." : "Premi Ctrl-C por kopii.",
    "{name} (invisible)" : "{name} (nevidebla)",
    "{name} (restricted)" : "{name} (limigita)",
    "There are no events for this filter" : "Neniu evento kun tiu ĉi filtrilo",
    "Activities" : "Aktivaĵoj"
},
"nplurals=2; plural=(n != 1);");
